@@ -180,10 +180,6 @@ public class Edge {
 		}
 	}
 
-	/*public Double getW() {
-		return ew.;
-	}*/
-
 	String getWS() {		
 		return ew.toString();
 	}
@@ -285,86 +281,64 @@ public class Edge {
 
 	/**
 	 * This function takes a string and creates a TeXIcon from this.
-	 * Things like "2^(1+2)" or even "2*2/4" will cause Exceptions or give false results.
-	 * This function is only meant to be for polynomials. 
 	 * @param s String to be parsed.
 	 * @return
 	 */
 	public static TeXIcon getTeXIcon(JFrame parent, String s, int points) {
 		String latex = "";
-		try {
-			boolean print = true;		
-			s.replaceAll("ε", "\\varepsilon");			
-			while (s.length()>0) {			
-				int i = getNextOperator(s);
-				if (i!=-1) {
-					String op = ""+s.charAt(i);
-					String start = s.substring(0, i);
+		try {				
+			int openBracket = 0;
+			boolean waitingForDenominator = false;
+			String nominator = "";			
+			s.replaceAll("ε", "\\varepsilon");	
+			s.replaceAll(" ", "");
+			for (int i=0;i<s.length(); i++) {
+				String c = ""+s.charAt(i);	
+				if (c.equals("(")) openBracket++;				
+				if (c.equals(")")) openBracket--;				
+				if ( (c.equals("+") || c.equals("-") || c.equals("*") || 
+						(c.equals(")") &&  (i+1)<s.length() && !(s.charAt(i+1)+"").equals("/")) ) && openBracket == 0) {
+					String start = s.substring(0, i+1);										
+					if (waitingForDenominator) {
+						if (c.equals(")")) {
+							latex += "\\frac{"+nominator+"}{"+start+"}";
+						} else {
+							latex += "\\frac{"+nominator+"}{"+start.substring(0, i)+"}"+c;
+						}
+						waitingForDenominator = false;
+					} else {
+						latex += start;
+					}
 					s = s.substring(i+1, s.length());
-					if (op.equals("+") || op.equals("-") || op.equals("*")) {
-						if (print) {
-							latex += start;							
-						}
-						if (!op.equals("*")) {
-							latex += op;
-						} else {
-							//formula.addSymbol("cdot");
-						}					
-						print = true;
-					}
-					if (op.equals("/")) {
-						i = getNextOperator(s);
-						String s2;
-						if (i!=-1) {
-							s2 = s.substring(0, i);
-						} else {
-							s2 = s;
-						}
-						if (op.equals("/")) {
-							latex += "\\frac{"+start+"}{"+s2+"}";
-						}
-						print = false;
-					}
-				} else {
-					if (print) {
-						latex += s;
-					}
-					s = "";
+					i=-1;
+				}
+				if (c.equals("/")) {					
+					nominator = s.substring(0, i);
+					s = s.substring(i+1, s.length());
+					i=-1;
+					waitingForDenominator = true;
 				}
 			}
+			if (waitingForDenominator) {
+				latex += "\\frac{"+nominator+"}{"+s+"}";				
+			} else {
+				latex += s;
+			}			
+			latex = latex.replaceAll("\\*", Configuration.getInstance().getGeneralConfig().getTimesSymbol());			
+			latex = latex.replaceAll("\\(", "{(");
+			latex = latex.replaceAll("\\)", ")}");
 			logger.debug("LaTeX string:"+latex);		
 			TeXFormula formula = new TeXFormula(latex);//
 			formula = new TeXFormula("\\mathbf{"+latex+"}");
 			return formula.createTeXIcon(TeXConstants.ALIGN_CENTER, points);
 		} catch(Exception e) {
-			JOptionPane.showMessageDialog(parent, "Invalid weight string:\n"+latex, "Invalid input", JOptionPane.ERROR_MESSAGE);
+			e.printStackTrace();
+			JOptionPane.showMessageDialog(parent, "Invalid weight string:\n"+latex+"\nError:\n"+e.getMessage(), "Invalid input", JOptionPane.ERROR_MESSAGE);
 			TeXFormula formula = new TeXFormula("Syntax Error");
 			return formula.createTeXIcon(TeXConstants.ALIGN_CENTER, points); 
 		}		
 	}
 	
-	private static int getNextOperator(String s) {
-		int min = s.length()+1;
-		int i = s.indexOf("+");
-		if (i!=-1) {
-			min = i;
-		}
-		i = s.indexOf("-");
-		if (i!=-1 && min>i) {
-			min = i;
-		}
-		i = s.indexOf("*");
-		if (i!=-1 && min>i) {
-			min = i;
-		}
-		i = s.indexOf("/");
-		if (i!=-1 && min>i) {
-			min = i;
-		}
-		if (min==s.length()+1) return -1;
-		return min;
-	}
-
 	public void setK1(int k1) {
 		double correction = 0;
 		/*if (frc != null) {					
